import json
import smtplib
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
import urllib.parse

class EmailService:
    def __init__(self):
        self.smtp_server = ""
        self.smtp_port = 0
        self.smtp_user = ""
        self.smtp_pass = ""
        self.host_name = ""
        self.load_config()

    def load_config(self):
        with open("config.json", "r") as config_file:
            config_data = json.load(config_file)
            email_config = config_data.get("EMAIL", {})
            self.smtp_server = email_config.get("SMTP_SERVER", "")
            self.smtp_port = email_config.get("SMTP_PORT", 587)
            self.smtp_user = email_config.get("SMTP_USER", "")
            self.smtp_pass = email_config.get("SMTP_PASS", "")

            host_config = config_data.get("HOST", {})
            self.host_name = host_config.get("HOST_NAME","")


    def send_mail(self, recipient_email, subject, message):
        msg = MIMEMultipart()
        msg['From'] = self.smtp_user
        msg['To'] = recipient_email
        msg['Subject'] = subject
        msg.attach(MIMEText(message, 'plain'))

        with smtplib.SMTP(self.smtp_server, self.smtp_port) as server:
            server.starttls()
            server.login(self.smtp_user, self.smtp_pass)
            server.sendmail(self.smtp_user, recipient_email, msg.as_string())

# def main():
#     email_service = EmailService()

#     user_email = "felix@asprime.co.ke"
#     subject = "Test Email"
#     message = "This is a test email message."

#     email_service.send_mail(user_email, subject, message)
#     print("Email sent.")

# if __name__ == "__main__":
#     main()
